EventWatcher

Struct EventWatcher 

pub struct EventWatcher { /* private fields */ }

Implementations

Source

impl EventWatcher

pub fn noop() -> Self

pub fn spawn( path: String, since_event_id: FSEventStreamEventId, latency: f64, ) -> (dev_t, EventWatcher)

Methods from Deref<Target = Receiver<Vec<FsEvent>>>

pub fn try_recv(&self) -> Result<T, TryRecvError>

Attempts to receive a message from the channel without blocking.

This method will either receive a message from the channel immediately or return an error if the channel is empty.

If called on a zero-capacity channel, this method will receive a message only if there happens to be a send operation on the other side of the channel at the same time.

Examples
use crossbeam_channel::{unbounded, TryRecvError};

let (s, r) = unbounded();
assert_eq!(r.try_recv(), Err(TryRecvError::Empty));

s.send(5).unwrap();
drop(s);

assert_eq!(r.try_recv(), Ok(5));
assert_eq!(r.try_recv(), Err(TryRecvError::Disconnected));
pub fn recv(&self) -> Result<T, RecvError>

Blocks the current thread until a message is received or the channel is empty and disconnected.

If the channel is empty and not disconnected, this call will block until the receive operation can proceed. If the channel is empty and becomes disconnected, this call will wake up and return an error.

If called on a zero-capacity channel, this method will wait for a send operation to appear on the other side of the channel.

Examples
use std::thread;
use std::time::Duration;
use crossbeam_channel::{unbounded, RecvError};

let (s, r) = unbounded();

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    s.send(5).unwrap();
    drop(s);
});

assert_eq!(r.recv(), Ok(5));
assert_eq!(r.recv(), Err(RecvError));
pub fn recv_timeout(&self, timeout: Duration) -> Result<T, RecvTimeoutError>

Waits for a message to be received from the channel, but only for a limited time.

If the channel is empty and not disconnected, this call will block until the receive operation can proceed or the operation times out. If the channel is empty and becomes disconnected, this call will wake up and return an error.

If called on a zero-capacity channel, this method will wait for a send operation to appear on the other side of the channel.

Examples
use std::thread;
use std::time::Duration;
use crossbeam_channel::{unbounded, RecvTimeoutError};

let (s, r) = unbounded();

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    s.send(5).unwrap();
    drop(s);
});

assert_eq!(
    r.recv_timeout(Duration::from_millis(500)),
    Err(RecvTimeoutError::Timeout),
);
assert_eq!(
    r.recv_timeout(Duration::from_secs(1)),
    Ok(5),
);
assert_eq!(
    r.recv_timeout(Duration::from_secs(1)),
    Err(RecvTimeoutError::Disconnected),
);
pub fn recv_deadline(&self, deadline: Instant) -> Result<T, RecvTimeoutError>

Waits for a message to be received from the channel, but only before a given deadline.

If the channel is empty and not disconnected, this call will block until the receive operation can proceed or the operation times out. If the channel is empty and becomes disconnected, this call will wake up and return an error.

If called on a zero-capacity channel, this method will wait for a send operation to appear on the other side of the channel.

Examples
use std::thread;
use std::time::{Instant, Duration};
use crossbeam_channel::{unbounded, RecvTimeoutError};

let (s, r) = unbounded();

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    s.send(5).unwrap();
    drop(s);
});

let now = Instant::now();

assert_eq!(
    r.recv_deadline(now + Duration::from_millis(500)),
    Err(RecvTimeoutError::Timeout),
);
assert_eq!(
    r.recv_deadline(now + Duration::from_millis(1500)),
    Ok(5),
);
assert_eq!(
    r.recv_deadline(now + Duration::from_secs(5)),
    Err(RecvTimeoutError::Disconnected),
);
pub fn is_empty(&self) -> bool

Returns true if the channel is empty.

Note: Zero-capacity channels are always empty.

Examples
use crossbeam_channel::unbounded;

let (s, r) = unbounded();

assert!(r.is_empty());
s.send(0).unwrap();
assert!(!r.is_empty());
pub fn is_full(&self) -> bool

Returns true if the channel is full.

Note: Zero-capacity channels are always full.

Examples
use crossbeam_channel::bounded;

let (s, r) = bounded(1);

assert!(!r.is_full());
s.send(0).unwrap();
assert!(r.is_full());
pub fn len(&self) -> usize

Returns the number of messages in the channel.

Examples
use crossbeam_channel::unbounded;

let (s, r) = unbounded();
assert_eq!(r.len(), 0);

s.send(1).unwrap();
s.send(2).unwrap();
assert_eq!(r.len(), 2);
pub fn capacity(&self) -> Option<usize>

If the channel is bounded, returns its capacity.

Examples
use crossbeam_channel::{bounded, unbounded};

let (_, r) = unbounded::<i32>();
assert_eq!(r.capacity(), None);

let (_, r) = bounded::<i32>(5);
assert_eq!(r.capacity(), Some(5));

let (_, r) = bounded::<i32>(0);
assert_eq!(r.capacity(), Some(0));
pub fn iter(&self) -> Iter<'_, T>

A blocking iterator over messages in the channel.

Each call to next blocks waiting for the next message and then returns it. However, if the channel becomes empty and disconnected, it returns None without blocking.

Examples
use std::thread;
use crossbeam_channel::unbounded;

let (s, r) = unbounded();

thread::spawn(move || {
    s.send(1).unwrap();
    s.send(2).unwrap();
    s.send(3).unwrap();
    drop(s); // Disconnect the channel.
});

// Collect all messages from the channel.
// Note that the call to `collect` blocks until the sender is dropped.
let v: Vec<_> = r.iter().collect();

assert_eq!(v, [1, 2, 3]);
pub fn try_iter(&self) -> TryIter<'_, T>

A non-blocking iterator over messages in the channel.

Each call to next returns a message if there is one ready to be received. The iterator never blocks waiting for the next message.

Examples
use std::thread;
use std::time::Duration;
use crossbeam_channel::unbounded;

let (s, r) = unbounded::<i32>();

thread::spawn(move || {
    s.send(1).unwrap();
    thread::sleep(Duration::from_secs(1));
    s.send(2).unwrap();
    thread::sleep(Duration::from_secs(2));
    s.send(3).unwrap();
});

thread::sleep(Duration::from_secs(2));

// Collect all messages from the channel without blocking.
// The third message hasn't been sent yet so we'll collect only the first two.
let v: Vec<_> = r.try_iter().collect();

assert_eq!(v, [1, 2]);
pub fn same_channel(&self, other: &Receiver<T>) -> bool

Returns true if receivers belong to the same channel.

Examples
use crossbeam_channel::unbounded;

let (_, r) = unbounded::<usize>();

let r2 = r.clone();
assert!(r.same_channel(&r2));

let (_, r3) = unbounded();
assert!(!r.same_channel(&r3));